@@ -6,12 +6,12 @@ import json
 from urllib import urlencode
 
 import requests
-from rauth.hook import OAuth1Hook
+from requests_oauthlib import OAuth1
 
 from query import Resolve, Table, Submit, Insert, Facets, Flag, Geopulse, Geocode, Diffs, Match, Multi, Clear
 
 API_V3_HOST = "http://api.v3.factual.com"
-DRIVER_VERSION_TAG = "factual-python-driver-1.3.2"
+DRIVER_VERSION_TAG = "factual-python-driver-1.4.0"
 
 class Factual(object):
     def __init__(self, key, secret, timeout=None):
@@ -70,13 +70,15 @@ class Factual(object):
         return Multi(self.api, queries).make_request()
 
     def _generate_token(self, key, secret):
-        access_token = OAuth1Hook(consumer_key=key, consumer_secret=secret, header_auth=True)
+        access_token = OAuth1(key, secret)
         return access_token
 
 
 class API(object):
     def __init__(self, access_token, timeout):
-        self.client = requests.session(hooks={'pre_request': access_token}, prefetch=False, timeout=timeout)
+        self.client = requests.Session()
+        self.client.auth = access_token
+        self.client.timeout = timeout
 
     def get(self, query):
         response = self._handle_request(query.path, query.params, self._make_get_request)
@@ -132,7 +134,7 @@ class API(object):
 
     def _make_get_request(self, url, params):
         headers = {'X-Factual-Lib': DRIVER_VERSION_TAG}
-        return self.client.get(url, headers=headers, params=params)
+        return self.client.get(url, headers=headers, params=params, timeout=self.client.timeout)
 
     def _make_post_request(self, url, params):
         headers = {'X-Factual-Lib': DRIVER_VERSION_TAG, 'content-type': 'application/x-www-form-urlencoded'}
