@@ -7,6 +7,9 @@ class Submit(Write):
     def values(self, values):
         return self._copy({'values': values})
 
+    def clear_blanks():
+        return self._copy({'clear_blanks': True})
+
     def _path(self):
         path = 't/' + self.table
         if self.factual_id:
